sboa: Secretary Bird Optimization Algorithm

View source: R/sboa.R

sboaR Documentation

Secretary Bird Optimization Algorithm

Description

General-purpose continuous optimization using the Secretary Bird Optimization Algorithm (SBOA).

Usage

sboa(
  fn,
  lower,
  upper,
  n_agents = 30,
  max_iter = 500,
  ...,
  verbose = TRUE,
  seed = NULL
)

Arguments

fn

Objective function to be minimized, or a character string naming a built-in benchmark function such as "F1".

lower

Lower bounds for decision variables.

upper

Upper bounds for decision variables.

n_agents

Number of search agents.

max_iter

Maximum number of iterations.

...

Additional arguments passed to fn.

verbose

Logical; if TRUE, progress is printed.

seed

Optional random seed.

Value

An object of class "sboa".

References

Fu, W., Wang, K., Liu, J., et al. (2024). Secretary Bird Optimization Algorithm. Artificial Intelligence Review. DOI: 10.1007/s10462-024-10729-y

Examples

sphere <- function(x) sum(x^2)

res <- sboa(
  fn = sphere,
  lower = rep(-10, 5),
  upper = rep(10, 5),
  n_agents = 10,
  max_iter = 20,
  seed = 123,
  verbose = FALSE
)

res2 <- sboa(
  fn = "F1",
  lower = rep(-100, 5),
  upper = rep(100, 5),
  n_agents = 10,
  max_iter = 20,
  seed = 123,
  verbose = FALSE
)

print(res)
print(res2)
list_benchmarks()
get_benchmark("F9")

SBOAtools documentation built on May 3, 2026, 9:06 a.m.