| sboa | R Documentation |
General-purpose continuous optimization using the Secretary Bird Optimization Algorithm (SBOA).
sboa(
fn,
lower,
upper,
n_agents = 30,
max_iter = 500,
...,
verbose = TRUE,
seed = NULL
)
fn |
Objective function to be minimized, or a character string
naming a built-in benchmark function such as |
lower |
Lower bounds for decision variables. |
upper |
Upper bounds for decision variables. |
n_agents |
Number of search agents. |
max_iter |
Maximum number of iterations. |
... |
Additional arguments passed to |
verbose |
Logical; if |
seed |
Optional random seed. |
An object of class "sboa".
Fu, W., Wang, K., Liu, J., et al. (2024). Secretary Bird Optimization Algorithm. Artificial Intelligence Review. DOI: 10.1007/s10462-024-10729-y
sphere <- function(x) sum(x^2)
res <- sboa(
fn = sphere,
lower = rep(-10, 5),
upper = rep(10, 5),
n_agents = 10,
max_iter = 20,
seed = 123,
verbose = FALSE
)
res2 <- sboa(
fn = "F1",
lower = rep(-100, 5),
upper = rep(100, 5),
n_agents = 10,
max_iter = 20,
seed = 123,
verbose = FALSE
)
print(res)
print(res2)
list_benchmarks()
get_benchmark("F9")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.